==> vue-cli-plugin-config-0.0.2.tgz: package/index.js <==
const path = require('path')
const fs = require('fs')
const yml = require('js-yaml')

module.exports = (api, projectOptions) => {
  if (!process.env.NODE_ENV) process.env.NODE_ENV = 'development'

  const context = api.getCwd()
  const file = path.resolve(context, `config/${process.env.NODE_ENV}.env.js`)
  const fileExist = fs.existsSync(file)
  if (!fileExist) throw new Error(`config/${process.env.NODE_ENV}.env.js 文件不存在`)

  // 填充 'process.env' 对象
  const params = require(file)
  if (!params.NODE_ENV) params.NODE_ENV = process.env.NODE_ENV
  const pkg = require(path.resolve(context, 'package.json'))
  params.PKG_VERSION = pkg.version
  params.PKG_NAME = pkg.name
  autoTransform(params)

  api.chainWebpack(webpackConfig => {
    webpackConfig.plugin('define')
      .init((plugin, args) => {
        if (!args) args = []
        if (args.length === 9) args[0] = {}
        if (!args[0]['process.env']) args[0]['process.env'] = {}
        args[0]['process.env'] = Object.assign(args[0]['process.env'], params)
        return new plugin(...args)
      })
  })
}

function autoTransform(objectOrArray) {
  if (typeof objectOrArray === 'object') { // 数组或对象
    if (objectOrArray instanceof Array) { // 处理数组
      objectOrArray.forEach((item, idx) => {
        if (typeof item === 'string') {
          objectOrArray[idx] = JSON.stringify(item)
        } else if (typeof item === 'object') { // 数组或对象
          objectOrArray[idx] = autoTransform(item)
        }
      })
    } else { // 处理对象
      for (const key in objectOrArray) {
        if (typeof objectOrArray[key] === 'string') {
          objectOrArray[key] = JSON.stringify(objectOrArray[key])
        } else if (typeof objectOrArray[key] === 'object'){ // 数组或对象
          objectOrArray[key] = autoTransform(objectOrArray[key])
        }
      }
    }
  }
  return objectOrArray
}

==> vue-cli-plugin-config-0.1.1.tgz: package/index.js <==
const path = require('path')
const fs = require('fs')
const yml = require('js-yaml')

module.exports = (api, projectOptions) => {
  if (!process.env.X_ENV) process.env.X_ENV = 'development'

  const context = api.getCwd()
  const file = path.resolve(context, `config/${process.env.X_ENV}.env.js`)
  const fileExist = fs.existsSync(file)
  if (!fileExist) throw new Error(`config/${process.env.X_ENV}.env.js 文件不存在`)

  // 填充 'process.env' 对象
  const params = require(file)
  if (!params.NODE_ENV) params.NODE_ENV = process.env.NODE_ENV
  const pkg = require(path.resolve(context, 'package.json'))
  params.PKG_VERSION = pkg.version
  params.PKG_NAME = pkg.name
  autoTransform(params)

  api.chainWebpack(webpackConfig => {
    webpackConfig.plugin('define')
      .init((plugin, args) => {
        if (!args) args = []
        if (args.length === 9) args[0] = {}
        if (!args[0]['process.env']) args[0]['process.env'] = {}
        args[0]['process.env'] = Object.assign(args[0]['process.env'], params)
        return new plugin(...args)
      })
  })
}

function autoTransform(objectOrArray) {
  if (typeof objectOrArray === 'object') { // 数组或对象
    if (objectOrArray instanceof Array) { // 处理数组
      objectOrArray.forEach((item, idx) => {
        if (typeof item === 'string') {
          objectOrArray[idx] = JSON.stringify(item)
        } else if (typeof item === 'object') { // 数组或对象
          objectOrArray[idx] = autoTransform(item)
        }
      })
    } else { // 处理对象
      for (const key in objectOrArray) {
        if (typeof objectOrArray[key] === 'string') {
          objectOrArray[key] = JSON.stringify(objectOrArray[key])
        } else if (typeof objectOrArray[key] === 'object'){ // 数组或对象
          objectOrArray[key] = autoTransform(objectOrArray[key])
        }
      }
    }
  }
  return objectOrArray
}
